==> istio-model-1.0.0-sources.jar: me/snowdrop/istio/api/authentication/v1alpha1/PeerAuthenticationMethodFluent.java <==
package me.snowdrop.istio.api.authentication.v1alpha1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Deprecated;
import com.fasterxml.jackson.annotation.JsonUnwrapped;
import java.lang.Boolean;

public interface PeerAuthenticationMethodFluent<A extends PeerAuthenticationMethodFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildParams instead.
 * @return The buildable object.
 */
@Deprecated public me.snowdrop.istio.api.authentication.v1alpha1.PeerAuthenticationMethod.Params getParams();
    public me.snowdrop.istio.api.authentication.v1alpha1.PeerAuthenticationMethod.Params buildParams();
    public A withParams(me.snowdrop.istio.api.authentication.v1alpha1.PeerAuthenticationMethod.Params params);
    public Boolean hasParams();
    public A withJwtParams(JwtParams jwtParams);
    public PeerAuthenticationMethodFluent.JwtParamsNested<A> withNewJwtParams();
    public PeerAuthenticationMethodFluent.JwtParamsNested<A> withNewJwtParamsLike(JwtParams item);
    public A withMtlsParams(MtlsParams mtlsParams);
    public PeerAuthenticationMethodFluent.MtlsParamsNested<A> withNewMtlsParams();
    public PeerAuthenticationMethodFluent.MtlsParamsNested<A> withNewMtlsParamsLike(MtlsParams item);

    public interface JwtParamsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,JwtParamsFluent<PeerAuthenticationMethodFluent.JwtParamsNested<N>>{

        
    public N and();    public N endJwtParams();
}
    public interface MtlsParamsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,MtlsParamsFluent<PeerAuthenticationMethodFluent.MtlsParamsNested<N>>{

        
    public N and();    public N endMtlsParams();
}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/authentication/v1alpha1/PeerAuthenticationMethodFluent.java <==
package me.snowdrop.istio.api.authentication.v1alpha1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Deprecated;
import com.fasterxml.jackson.annotation.JsonUnwrapped;
import java.lang.Boolean;

public interface PeerAuthenticationMethodFluent<A extends PeerAuthenticationMethodFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildParams instead.
 * @return The buildable object.
 */
@Deprecated public PeerAuthenticationMethod.Params getParams();
    public PeerAuthenticationMethod.Params buildParams();
    public A withParams(PeerAuthenticationMethod.Params params);
    public Boolean hasParams();
    public A withJwtParams(JwtParams jwtParams);
    public PeerAuthenticationMethodFluent.JwtParamsNested<A> withNewJwtParams();
    public PeerAuthenticationMethodFluent.JwtParamsNested<A> withNewJwtParamsLike(JwtParams item);
    public A withMtlsParams(MtlsParams mtlsParams);
    public PeerAuthenticationMethodFluent.MtlsParamsNested<A> withNewMtlsParams();
    public PeerAuthenticationMethodFluent.MtlsParamsNested<A> withNewMtlsParamsLike(MtlsParams item);

    public interface JwtParamsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,JwtParamsFluent<PeerAuthenticationMethodFluent.JwtParamsNested<N>>{

        
    public N and();    public N endJwtParams();
}
    public interface MtlsParamsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,MtlsParamsFluent<PeerAuthenticationMethodFluent.MtlsParamsNested<N>>{

        
    public N and();    public N endMtlsParams();
}


}
